@@ -20,7 +20,7 @@ a reference to the fields form configuration hash
 
 a reference to an hash which contains information about the column (see FormEngine::DBSQL::PGSQL).
 
-=back
+=over
 
 The handler now modifies the fields configuration hash and can
 therefore use information out of the column information hash (which he
@@ -79,12 +79,6 @@ sub _dbsql_dthandle_date {
   $res->{templ} = 'text';
   $res->{MAXLEN} = 10;
   $res->{SIZE} = 10;
-  $res->{ERROR} = 'date';
-}
-
-sub _dbsql_dthandle_text {
-  my($self,$res) = @_;
-  $res->{templ} = 'textarea';
 }
 
 1;
